@@ -4,6 +4,7 @@ from typing_extensions import TypeGuard
 from vellum.workflows.descriptors.base import BaseDescriptor
 from vellum.workflows.descriptors.exceptions import InvalidExpressionException
 from vellum.workflows.descriptors.utils import resolve_value
+from vellum.workflows.expressions.comparison_utils import prepare_comparison_operands
 from vellum.workflows.state.base import BaseState
 
 LHS = TypeVar("LHS")
@@ -34,7 +35,13 @@ class LessThanExpression(BaseDescriptor[bool], Generic[LHS, RHS]):
         lhs = resolve_value(self._lhs, state)
         rhs = resolve_value(self._rhs, state)
 
+        # Parse string operands as numbers when comparing with numeric types
+        lhs, rhs = prepare_comparison_operands(lhs, rhs)
+
         if not has_lt(lhs):
             raise InvalidExpressionException(f"'{lhs.__class__.__name__}' must support the '<' operator")
 
-        return lhs < rhs
+        try:
+            return lhs < rhs
+        except TypeError as e:
+            raise InvalidExpressionException(str(e))
